==> haskell-persistent-template-2.5.1.6-25-i686.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-template
version: 2.5.1.6
id: persistent-template-2.5.1.6-L8I8OFknJ94B45VQtfh03i
key: persistent-template-2.5.1.6-L8I8OFknJ94B45VQtfh03i
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Persist.TH
abi: 5e2d1164f9155702a84c9f56d7dd987d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-template-2.5.1.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-template-2.5.1.6
data-dir: /usr/share/i386-linux-ghc-8.0.1/persistent-template-2.5.1.6
hs-libraries: HSpersistent-template-2.5.1.6-L8I8OFknJ94B45VQtfh03i
depends:
    aeson-1.0.2.1-FRh8NWzqPiiuj2q5G5H5S
    aeson-compat-0.3.6-BsHypGyMVlG1Hc713JXmeP base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1 ghc-prim-0.5.0.0
    http-api-data-0.3.5-1t0cBcsLHEz8lHj2KjdFhq
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.20.1-A1T5ZL9snf64SauyreP6SE
    path-pieces-0.2.1-EkkcipvGNTB6jNvz5dfdoN
    persistent-2.6-Lw6Qrv3XKz9DVUxp21c7T7
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
haddock-interfaces: /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock
haddock-html: /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-template-2.5.1.6-31-i686.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-template
version: 2.5.1.6
id: persistent-template-2.5.1.6-52x9O9brU3X39av9F2UsbA
key: persistent-template-2.5.1.6-52x9O9brU3X39av9F2UsbA
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Persist.TH
abi: 82fc8b0e1f87c560888c9eec4ad1a4cd
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-template-2.5.1.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-template-2.5.1.6
data-dir: /usr/share/i386-linux-ghc-8.0.1/persistent-template-2.5.1.6
hs-libraries: HSpersistent-template-2.5.1.6-52x9O9brU3X39av9F2UsbA
depends:
    aeson-1.0.2.1-580HLk2Nlp5BZ0wDg2BMVx
    aeson-compat-0.3.6-71fb3fe0LaJ6zE1uHxEp86 base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1 ghc-prim-0.5.0.0
    http-api-data-0.3.5-FPMXWzIBll8HRLyB28KwM1
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.20.2-JTAIQ2hISya9krzRihq4vG
    path-pieces-0.2.1-EkkcipvGNTB6jNvz5dfdoN
    persistent-2.6-IW9EjImAw3vJ6wSbFCA7c6
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
haddock-interfaces: /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock
haddock-html: /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
